# clax

handy classifiers in jax

# Installation

`pip install .`

For Apple silicon users with Sonoma 14.4+ wanting to try GPU acceleration (may need `ENABLE_PJRT_COMPATIBILITY=1`)

`pip install ".[metal]"`

or try equivalently from pypi

# Examples

Examples included in `examples` directory
